OED fields

The input fields for each OED file, grouped by file. Status is the field’s requirement level for property business:

R

Required

O

Optional

CR

Conditionally required (required in certain circumstances — see the field description)

n/a

Not applicable to this file / line of business

Line-of-business status for Cyber, Liability and Marine Cargo is carried in oed.json (Cyber/Liability/Marine Cargo field status); the table below shows the property status.

Location (Loc)

Field

Description

Data type

Status

Default

PortNumber

Portfolio number

varchar(20)

R

n/a

AccNumber

Account number

nvarchar(40)

R

n/a

LocNumber

Location number

nvarchar(20)

R

n/a

LocName

Location name

nvarchar(20)

O

n/a

LocGroup

Location group name

nvarchar(20)

O

n/a

CorrelationGroup

Correlation Group: indicates which locations should be correlated between each other in Oasis LMF.

int

O

n/a

IsPrimary

Whether the location in LocGroup is the primary building in the group

tinyint

O

1

IsTenant

Whether property is occupied by a tenant or not

tinyint

O

0

BuildingID

Unique building identification number

varchar(20)

O

n/a

LocInceptionDate

Location inception date - in ISO 8601 format: YYYY-MM-DD

smalldatetime

O

n/a

LocExpiryDate

Location expiry date - in ISO 8601 format: YYYY-MM-DD

smalldatetime

O

n/a

PercentComplete

Percentage of the construction project complete, entered as a proportion with values between 0 and 1 (e.g. 12% entered as 0.12). The completeness percentage is by the cost of the project.

decimal

O

1

CompletionDate

Construction project completion date - in ISO 8601 format: YYYY-MM-DD

date

O

n/a

CountryCode

Country code (based on ISO3166 alpha-2 codes)

char(2)

R

n/a

Latitude

Latitude in degrees (-90.0 to +90.0)

decimal

O

n/a

Longitude

Longitude in degrees (-180.0 to +180.0)

decimal

O

n/a

StreetAddress

Street address including house number

nvarchar(100)

O

n/a

PostalCode

Postcode: the highest resolution postcode most often used. (e.g. 5 digit zip for the US).

nvarchar(20)

O

n/a

City

City

nvarchar(50)

O

n/a

AreaCode

Code representing typically the largest sub-division in a country (e.g. State code). See AreaCode Values sheet for details.

nvarchar(20)

O

n/a

AreaName

Name relating to the AreaCode (e.g. State name). See AreaCode Values sheet for details.

nvarchar(50)

O

n/a

GeogSchemeXX

Geography scheme: Descriptor of the geography scheme used in relation to the geography name in the corresponding GeogName field (e.g. PC4). The ‘XX’ must be changed to an integer (GeogScheme1……> GeogScheme30 (max) etc) and the user can specify values in addition to those listed in the GeogScheme values list, but user defined scheme values must start with ‘X’.

varchar(5)

O

n/a

GeogNameXX

Geography name: Descriptor of the geographical area, using the scheme referenced in the corresponding GeogScheme field (e.g. SO31)

nvarchar(50)

O

n/a

AddressMatch

Address match from geocoder: indicating the resolution that the latitude / longitude represents

tinyint

O

0

GeocodeQuality

Geocode quality (values between 0 and 1 e.g. 80% is entered as 0.8)

float

O

n/a

Geocoder

Company name / version of geocoder. Free text field.

varchar(20)

O

n/a

OrgOccupancyScheme

Original occupancy scheme

varchar(10)

O

n/a

OrgOccupancyCode

Original occupancy code

varchar(100)

O

n/a

OrgConstructionScheme

Original construction scheme

varchar(10)

O

n/a

OrgConstructionCode

Original construction code

varchar(100)

O

n/a

OccupancyCode

OED occupancy code

int

O

1000

ConstructionCode

OED construction code

int

O

5000

YearBuilt

Year built (4 digit year)

smallint

O

0

NumberOfStoreys

Number of storeys (-1 = Unknown No. storeys - low rise), (-2 = Unknown No. storeys - mid rise), (-3 = Unknown No. storeys = high rise). Can be used with occupancy types where the number of storeys are unknown.

tinyint

O

0

NumberOfBuildings

Number of buildings. Default to 1 but user should enter ‘0’ if unknown.

int

O

1

FloorArea

Floor area: the total area across all floors

float

O

0

FloorAreaUnit

Units in which FloorArea is specified

tinyint

O

11

LocUserDef1

Location user defined field 1

varchar(100)

O

n/a

LocUserDef2

Location user defined field 2

varchar(100)

O

n/a

LocUserDef3

Location user defined field 3

varchar(100)

O

n/a

LocUserDef4

Location user defined field 4

varchar(100)

O

n/a

LocUserDef5

Location user defined field 5

varchar(100)

O

n/a

FlexiLocZZZ

Flexible field that is stored in FlexiLoc table in ModifierName = ZZZ

varchar(40)

O

n/a

LocPerilsCovered

Location perils covered

varchar(250)

R

n/a

BuildingTIV

Building Total Insured Value

float

O

0

OtherTIV

Other Building Insured Value (primarily aimed at specific US policies). For motor exposures, use this field for TIV along with appropriate motor construction code.

float

O

0

ContentsTIV

Contents Total Insured Value

float

O

0

BITIV

Business Interruption (BI) Total Insured Value. Enter an annualized amount, and use LocDed4BI and LocLimit4BI fields for non-annualized values

float

O

0

BIPOI

BI period of indemnity (in days, in increments of 0.5 days). Default value = 365 (1 year).

float

O

365

LocCurrency

Location currency

char(3)

R

n/a

LocGrossPremium

Gross premium amount at location level

float

O

0

LocTax

Insurance tax amount at location level

float

O

0

LocBrokerage

Brokerage amount at location level

float

O

0

LocNetPremium

Net premium at location level

float

O

0

NonCatGroundUpLoss

Ground-Up non-cat loss value prior to the application of non-cat policy terms

float

O

0

LocParticipation

Share of the risk that the insurer covers for this location, entered as a proportion with values between 0 to 1 (e.g. 12% entered as 0.12). Usually used in binders or offshore.

float

O

1

PayoutBasis

Pay-out basis for the claim (whether depreciation is taken into account). ACV = RCV - depreciation.

tinyint

O

0

ReinsTag

User defined reinsurance tag to provide a further option for specifying reinsurance scope

varchar(20)

O

n/a

LocDedCode1Building

Location building deductible code

tinyint

O

0

LocDedType1Building

Location building deductible type

tinyint

CR

0

LocDed1Building

Location building deductible

float

CR

0

LocMinDed1Building

Location minimum building deductible

float

CR

0

LocMaxDed1Building

Location maximum building deductible

float

CR

0

LocDedCode2Other

Location other building deductible code

tinyint

O

0

LocDedType2Other

Location other building deductible type

tinyint

CR

0

LocDed2Other

Location other building deductible

float

CR

0

LocMinDed2Other

Location minimum other building deductible

float

CR

0

LocMaxDed2Other

Location maximum other building deductible

float

CR

0

LocDedCode3Contents

Location contents deductible code

tinyint

O

0

LocDedType3Contents

Location contents deductible type

tinyint

CR

0

LocDed3Contents

Location contents deductible

float

CR

0

LocMinDed3Contents

Location minimum contents deductible

float

CR

0

LocMaxDed3Contents

Location maximum contents deductible

float

CR

0

LocDedCode4BI

Location BI Deductible Code

tinyint

O

0

LocDedType4BI

Location BI Deductible Type

tinyint

CR

0

LocDed4BI

Location BI deductible

float

CR

0

LocMinDed4BI

Location minimum bi deductible

float

CR

0

LocMaxDed4BI

Location maximum bi deductible

float

CR

0

LocDedCode5PD

Location PD deductible code

tinyint

O

0

LocDedType5PD

Location PD deductible type

tinyint

CR

0

LocDed5PD

Location PD deductible

float

CR

0

LocMinDed5PD

Location minimum PD deductible

float

CR

0

LocMaxDed5PD

Location maximum PD deductible

float

CR

0

LocDedCode6All

Location blanket deductible code

tinyint

O

0

LocDedType6All

Location blanket deductible type

tinyint

CR

0

LocDed6All

Location site deductible

float

CR

0

LocMinDed6All

Location minimum blanket deductible

float

CR

0

LocMaxDed6All

Location maximum blanket deductible

float

CR

0

LocLimitCode1Building

Location building limit code

tinyint

O

0

LocLimitType1Building

Location building limit type

tinyint

CR

0

LocLimit1Building

Location building limit

float

CR

0

LocLimitCode2Other

Location other building limit code

tinyint

O

0

LocLimitType2Other

Location other building limit type

tinyint

CR

0

LocLimit2Other

Location other building limit

float

CR

0

LocLimitCode3Contents

Location contents limit code

tinyint

O

0

LocLimitType3Contents

Location contents limit type

tinyint

CR

0

LocLimit3Contents

Location contents limit

float

CR

0

LocLimitCode4BI

Location BI limit code

tinyint

O

0

LocLimitType4BI

Location BI limit type

tinyint

CR

0

LocLimit4BI

Location BI limit

float

CR

0

LocLimitCode5PD

Location PD limit code

tinyint

O

0

LocLimitType5PD

Location PD limit type

tinyint

CR

0

LocLimit5PD

Location PD limit

float

CR

0

LocLimitCode6All

Location site limit code

tinyint

O

0

LocLimitType6All

Location site limit type

tinyint

CR

0

LocLimit6All

Location site limit

float

CR

0

BIWaitingPeriod

BI waiting period (in days)

float

O

0

LocPeril

Perils for location financial terms

varchar(250)

CR

n/a

YearUpgraded

Year the building was upgraded (4 digit year)

smallint

O

0

SurgeLeakage

Storm leakage percentage entered as a proportion with values between 0 and 1 (0% to 100%) for Wind only policies

float

O

-999

SprinklerType

Sprinkler type

tinyint

O

0

PercentSprinklered

Percent sprinklered, entered as a proportion with values between 0 and 1 inclusive (0.5 = 50%); -999 is unknown

float

O

-999

RoofCover

Code that represents the material used to cover the roof

tinyint

O

0

RoofYearBuilt

Year the roof was last replaced (4 digit year)

smallint

O

0

RoofGeometry

Code that represents the shape of the roof

tinyint

O

0

RoofEquipment

captures if mechanical or electric equipment is braced on the roof and the impact this modifier will have on the losses.

tinyint

O

0

RoofFrame

Roof framing material

tinyint

O

0

RoofMaintenance

Captures the impact roof maintenance has on the losses

tinyint

O

0

BuildingCondition

Building condition

tinyint

O

0

RoofAttachedStructures

Code that identifies items mounted on the roof, such as A/C units, skylights, or dormers

tinyint

O

0

RoofDeck

Code that represents the materials used to construct the roof deck

tinyint

O

0

RoofPitch

Code that represents the slope of the roof

tinyint

O

0

RoofAnchorage

Code that represents the connections used to secure the roof support system to the walls

tinyint

O

0

RoofDeckAttachment

Code that represents the connections used to secure the roof deck to the underlying roof support system

tinyint

O

0

RoofCoverAttachment

Code that represents the connections used to secure the roof covering to the roof deck

tinyint

O

0

GlassType

Code that represents the type of glass used in the building

tinyint

O

0

LatticeType

Code that represents the type of web used for H-shaped steel

tinyint

O

0

FloodZone

Flood zone. Free text field.

varchar(20)

O

n/a

SoftStory

Code that indicates if there is structural weakness at any floor. First floor garages and taller first floors are likely to exhibit soft-story behaviour.

tinyint

O

0

Basement

Code that defines if there is a basement and if so whether it is finished or unfinished

tinyint

O

0

BasementLevelCount

Indicates the number of basement levels in a structure (supports up to 5 levels; for more than 5, enter 5).

tinyint

O

0

WindowProtection

Code that represents the wind protection systems used on the windows

tinyint

O

0

FoundationType

Code that represents the construction type of the building’s foundation

tinyint

O

0

WallAttachedStructure

Code that represents a structure that is physically attached to the building, such as garage or balcony

tinyint

O

0

AppurtenantStructure

Code for the appurtenant building, such as shed or detached garage

tinyint

O

0

ConstructionQuality

Construction quality

tinyint

O

0

GroundEquipment

Captures whether mechanical or electrical equipment are present on the ground level of a building and impact it has on losses

tinyint

O

0

EquipmentBracing

Identifies where mechanical or electrical equipment is held in place by bracing

tinyint

O

0

Flashing

Refers to the impact the quality of the flashing or coping on a roof has on losses

tinyint

O

0

BuildingShape

Code that represents the shape of the building

tinyint

O

0

ShapeIrregularity

Identifies vertical irregularities, overhangs and setbacks in the building design

tinyint

O

0

Pounding

Code that represents the distance to the closest structure, which if not adequate, can cause the two structures to collide during earthquake shaking

tinyint

O

0

Ornamentation

Code that represents the amount of decorative elements attached to the exterior of a building

tinyint

O

0

SpecialEQConstruction

Presence of a seismic base isolation system

tinyint

O

0

Retrofit

Presence of retro fit connectivity between walls and floor for retro fit buildings

tinyint

O

0

CrippleWall

Presence of cripple walls on the first floor or frame buildings

tinyint

O

0

FoundationConnection

Connection of frame to foundation with or without bolts

tinyint

O

0

ShortColumn

Code that indicates if there are short columns in the building

tinyint

O

0

Fatigue

Captures signs of damage from prior earthquakes

tinyint

O

0

Cladding

The presence and material of exterior building cladding

tinyint

O

0

BIPreparedness

BI preparedness

tinyint

O

0

BIRedundancy

BI redundancy

tinyint

O

0

FirstFloorHeight

Height of the lowest floor (above ground) of the building with respect to local ground elevation (NOT relative to datum). First floor in the US is identical to ground floor in Europe.

float

O

-999

FirstFloorHeightUnit

Code for the unit of measure used to express FirstFloorHeight

tinyint

O

1

Datum

Datum reference for the elevation fields (e.g. NAVD88; WGS84)

varchar(20)

O

n/a

GroundElevation

Flood or Windstorm - Elevation of the local ground surface at the building at this location. This field represents the elevation of the grade (local ground surface) with respect to the datum (e.g. NAVD88).

float

O

-999

GroundElevationUnit

Code for the unit of measure used to express the GroundElevation

tinyint

O

1

Tank

Code that indicates if there are rooftop tanks on the adjoining higher buildings

tinyint

O

0

Redundancy

Indicates whether there are multiple lateral load resisting elements, such as frames or shear walls

tinyint

O

0

InternalPartition

Interior wall partitions or chimneys made from URM

tinyint

O

0

ExternalDoors

Wind resistant doors, doors with a certain rating of hurricane protection

tinyint

O

0

Torsion

Code that represents the layout of structural elements that can lead to torsional loads

tinyint

O

0

MechanicalEquipmentSide

Mechanical or electrical equipment at the side

tinyint

O

0

ContentsWindVuln

Contents relative vulnerability to windstorm or tornado

tinyint

O

0

ContentsFloodVuln

Contents relative vulnerability to flood

tinyint

O

0

ContentsQuakeVuln

Contents relative vulnerability to earthquake

tinyint

O

0

SmallDebris

Code that identifies whether small debris are present within 200 meters of the structure

tinyint

O

0

FloorsOccupied

Number of floors in the building that are occupied (separated by semi-colons). Each floor occupied is separated by a semi-colon. Ranges are not accepted. 0 = ground floor, -1 = first level of basement, -2 = second level of basement; 1 = first floor, 2 = second floor, etc.

varchar(255)

O

n/a

FloodDefenseHeight

Height of any site specific flood defenses protecting the property with respect to local ground elevation (NOT to datum).

float

O

-999

FloodDefenseHeightUnit

Code for the unit of measure used to express the FloodDefenseHeight

tinyint

O

1

FloodDebrisResilience

Shows if building is vulnerable to floating debris

tinyint

O

0

BaseFloodElevation

Water surface elevation (relative to datum - this is NOT a flood depth) corresponding to a flood having a 1% probability of being equaled or exceeded in a given year. A value of -999 for this field represents unknown/default.

float

O

-999

BaseFloodElevationUnit

Code for the unit of measure used to express the BaseFloodElevation

tinyint

O

1

BuildingHeight

Total height of the structure

float

O

-999

BuildingHeightUnit

Units of the BuildingHeight

tinyint

O

1

BuildingValuation

Field for third party valuation data

varchar(20)

O

n/a

TreeExposure

Secondary modifier coding density of trees adjacent to structure

tinyint

O

0

Chimney

Code that indicates if the structure has a chimney and, if so, the height of the chimney

tinyint

O

0

BuildingType

Building type (e.g. detached, terraced, etc)

tinyint

O

0

Packaging

Describes the susceptibility of the packaging of a risk to the peril

tinyint

O

0

Protection

Describes the level of protection from the specific peril

tinyint

O

0

SalvageProtection

The salvage potential of a particular product

tinyint

O

0

ValuablesStorage

Where the specie element is stored

tinyint

O

0

DaysHeld

Number of days cargo is kept at port or the duration of an exhibition. Values between 0 to 1825 (up to 5 years). Default = 365.

smallint

O

365

BrickVeneer

Code that represents the proportion of external walls that consist of brick veneer. See ‘OtherValues’ for list of valid values.

tinyint

O

0

FEMACompliance

Indicates whether the building is in compliance with the FEMA flood zone requirements in both design and construction

tinyint

O

0

CustomFloodSOP

Standard of flood protection return period; values from 0-10,000

tinyint

O

0

CustomFloodZone

User-defined flood zone

varchar(20)

O

n/a

MultiStoryHall

Code that indicates if the building has a multi-story hall

tinyint

O

0

BuildingExteriorOpening

Code that represents the proportion of exterior walls that are open (i.e. have windows or doors). See ‘OtherValues’ for list of valid values.

tinyint

O

0

ServiceEquipmentProtection

Code that indicates whether the service equipment is protected from flood

tinyint

O

0

TallOneStory

The height of the taller than usual one-story building (e.g. gymnasium, auditorium, church, etc.)

tinyint

O

0

TerrainRoughness

Terrain conditions around the building.

tinyint

O

0

Payroll

Total payroll

int

O

n/a

StaticMotorVehicle

Identifies whether a risk is static or dynamic (moves from location to location)

tinyint

O

0

CondTag

Identifies a group of locations which are subject to one or more conditions.

varchar(20)

CR

n/a

OEDVersion

The OED schema version of the file - ‘major, minor, patch’ format i.e. (2.0.0)

varchar(10)

O

latest version

IsAggregate

Agggrated Data based on NumberOfBuildings field

tinyint

O

0

OccupantPeriod

Period/time of day/season for ‘NumberOfOccupants’

tinyint

O

0

SoilType

0 = no soil information, 1 = time averaged shear-wave velocity to 30m depth (vs30 (m/s))

tinyint

O

0

SoilValue

The value associated with the SoilType and the corresponding unit

float

O

0

NumberOfOccupants

Total number of occupants at a location (e.g., residents, employees, visitors)

int

O

0

OccupantUnderfive

Number of occupants aged under 5 years

int

O

0

OccupantOver65

Number of occupants aged over 65 years

int

O

0

OccupantAge5to65

Number of occupants aged 5-65 years

int

O

0

OccupantFemale

Number of female occupants

int

O

0

OccupantMale

Number of male occupants

int

O

0

OccupantOther

Number of occupants who identify as non-binary or other gender

int

O

0

OccupantUrban

Number of occupants classed as living in an urban area

int

O

0

OccupantRural

Number of occupants classed as living in a rural area

int

O

0

OccupantPoverty

Number of occupants classed as living in poverty

int

O

0

OccupantRefugee

Number of occupants with refugee status

int

O

0

OccupantUnemployed

Number of occupants classed as unemployed

int

O

0

OccupantDisability

Number of occupants with a disability

int

O

0

OccupantEthnicMinority

Number of ethnic minority occupants

int

O

0

OccupantTemporary

Number of temporary occupants (e.g., tourists)

int

O

0

OriginalCurrency

Original currency in which the business has been written before any conversions

char(3)

O

n/a

RateOfExchange

Rate of exchange used to convert the terms from OriginalCurrency

float

O

0

OffshoreWaterDepth

Depth of water for offshore structures (in metres)

float

O

n/a

SectionLength

Length of line element associated with point location. Intended for line-assets, such as roads, railways and cables. Such an asset can be defined as a series of points along its length, and the ‘Length’ field describes the length associated with each point. E.g. if a road is coded as points at 2km intervals, then the ‘Length’ value is 2, and the TIV represents the value for that 2km stretch of road.

float

O

n/a

PowerCapacity

The electrical capacity (e.g. in MW) associated with an infrastructure asset. Intended for power generation and power transmission assets. E.g. power stations, turbines, cables, etc. Provide the generating capacity of each asset (e.g. for a turbine, this is the capacity of the turbine, not the windfarm).

float

O

n/a

VulnerabilitySetID

ID allowing custom location level vulnerability to be captured

int

O

n/a

BuildingFloodVuln

Building relative vulnerability to flood

tinyint

O

n/a

BIFloodVuln

BI relative vulnerability to flood

tinyint

O

n/a

Geom

Geometry of the location: refer to http://postgis.net/workshops/postgis-intro/geometries.html

varchar(250)

O

n/a

CodeProvision

Code provision for energy, water and communication infrastructure

tinyint

O

Anchorage

Anchorage of for energy, water and communication infrastructure

tinyint

O

DiameterOfPipeline

Diameter of pipeline

tinyint

O

VoltageOfEnergy

Voltage of energy infrastructure (applicable to substations, generation facilities and transmission)

tinyint

O

PumpingCapacity

Capacity of water pumping and treatment plants, in MGD (Millions gallons per day)

tinyint

O

SoilLiquefiable

Defines whether a soil is susceptible to liquefaction or not.

int

O

0

CommoditySchemeXX

Commodity scheme eg. Harmonised System Commodity Codes. See ‘Other Values’

varchar(5)

CR

n/a

CommodityCodeXX

Commodity code related to CommodityScheme. See ‘Commodity Values’.

varchar(10)

CR

n/a

CommodityVintageXX

Vintage of commodity scheme used (YYYY format)

smallint

O

0

Account (Acc)

Field

Description

Data type

Status

Default

PortNumber

Portfolio number

varchar(20)

R

n/a

PortName

Portfolio name

varchar(40)

O

n/a

PortNotes

Portfolio notes, longer description than allowed in portfolio name

varchar(200)

O

n/a

AccNumber

Account number

nvarchar(40)

R

n/a

AccName

Account name

nvarchar(100)

O

n/a

AccGroup

Account group, could use to group multiple accounts (e.g. for binders)

varchar(40)

O

n/a

AccStatus

Account status. Aside from predefined values, you can use other single character values for user specific purposes

char(1)

O

n/a

ExpiringAccNumber

Expiring account number

nvarchar(40)

O

n/a

CedantName

Cedant name (defined at account level)

varchar(40)

O

n/a

AccCurrency

Account currency

char(3)

R

n/a

AccUserDef1

Account user defined field 1

varchar(100)

O

n/a

AccUserDef2

Account user defined field 2

varchar(100)

O

n/a

AccUserDef3

Account user defined field 3

varchar(100)

O

n/a

AccUserDef4

Account user defined field 4

varchar(100)

O

n/a

AccUserDef5

Account user defined field 5

varchar(100)

O

n/a

FlexiAccZZZ

Flexible field that is stored in FlexiAcc table in ModifierName = ZZZ

varchar(40)

O

n/a

AccPeril

Perils for account financial terms

varchar(250)

CR

n/a

AccDedCode1Building

Account building deductible code

tinyint

O

0

AccDedType1Building

Account building deductible type

tinyint

CR

0

AccDed1Building

Account building deductible

float

CR

0

AccMinDed1Building

Account minimum building deductible

float

CR

0

AccMaxDed1Building

Account maximum building deductible

float

CR

0

AccDedCode2Other

Account other building deductible code

tinyint

O

0

AccDedType2Other

Account other building deductible type

tinyint

CR

0

AccDed2Other

Account other building deductible

float

CR

0

AccMinDed2Other

Account minimum other building deductible

float

CR

0

AccMaxDed2Other

Account maximum other building deductible

float

CR

0

AccDedCode3Contents

Account contents deductible code

tinyint

O

0

AccDedType3Contents

Account contents deductible type

tinyint

CR

0

AccDed3Contents

Account contents deductible

float

CR

0

AccMinDed3Contents

Account minimum contents deductible

float

CR

0

AccMaxDed3Contents

Account maximum contents deductible

float

CR

0

AccDedCode4BI

Account BI deductible code

tinyint

O

0

AccDedType4BI

Account BI deductible type

tinyint

CR

0

AccDed4BI

Account BI deductible

float

CR

0

AccMinDed4BI

Account minimum BI deductible

float

CR

0

AccMaxDed4BI

Account maximum BI deductible

float

CR

0

AccDedCode5PD

Account PD deductible code

tinyint

O

0

AccDedType5PD

Account PD deductible type

tinyint

CR

0

AccDed5PD

Account PD deductible

float

CR

0

AccMinDed5PD

Account minimum PD deductible

float

CR

0

AccMaxDed5PD

Account maximum PD deductible

float

CR

0

AccDedCode6All

Account blanket deductible code

tinyint

O

0

AccDedType6All

Account blanket deductible type

tinyint

CR

0

AccDed6All

Account blanket deductible

float

CR

0

AccMinDed6All

Account minimum blanket deductible

float

CR

0

AccMaxDed6All

Account maximum blanket deductible

float

CR

0

AccLimitCode1Building

Account building limit code

tinyint

O

0

AccLimitType1Building

Account building limit type

tinyint

CR

0

AccLimit1Building

Account building limit

float

CR

0

AccLimitCode2Other

Account other building limit code

tinyint

O

0

AccLimitType2Other

Account other building limit type

tinyint

CR

0

AccLimit2Other

Account other building limit

float

CR

0

AccLimitCode3Contents

Account contents limit code

tinyint

O

0

AccLimitType3Contents

Account contents limit type

tinyint

CR

0

AccLimit3Contents

Account contents limit

float

CR

0

AccLimitCode4BI

Account BI limit code

tinyint

O

0

AccLimitType4BI

Account BI limit type

tinyint

CR

0

AccLimit4BI

Account BI limit

float

CR

0

AccLimitCode5PD

Account PD limit code

tinyint

O

0

AccLimitType5PD

Account PD limit type

tinyint

CR

0

AccLimit5PD

Account PD limit

float

CR

0

AccLimitCode6All

Account blanket limit code

tinyint

O

0

AccLimitType6All

Account blanket limit type

tinyint

CR

0

AccLimit6All

Account blanket limit

float

CR

0

PolNumber

Policy layer number

varchar(20)

R

n/a

PolStatus

Policy layer status. Aside from predefined values, other single character values for user specific purposes can be used.

char(1)

O

n/a

PolInceptionDate

Policy inception date - in ISO 8601 format: YYYY-MM-DD

smalldatetime

O

n/a

PolExpiryDate

Policy expiry date - in ISO 8601 format: YYYY-MM-DD

smalldatetime

O

n/a

ProducerName

Producer name (defined at policy level)

varchar(40)

O

n/a

Underwriter

Underwriter name

varchar(40)

O

n/a

BranchName

Branch name

varchar(20)

O

n/a

LOB

Line of business (defined at policy level)

varchar(20)

O

n/a

ExpiringPolNumber

Expiring policy number

varchar(20)

O

n/a

PolPerilsCovered

Policy perils covered

varchar(250)

R

n/a

PolGrossPremium

Policy gross premium

float

O

0

PolTax

Policy insurance tax amount

float

O

0

PolBrokerage

Policy brokerage amount

float

O

0

PolNetPremium

Policy net premium

float

O

0

LayerNumber

Layer number

int

O

1

LayerParticipation

Insurance company share of the policy layer. Values between 0 to 1 (e.g. 12% entered as 0.12)

float

O

1

LayerLimit

Policy layer limit (always treated as amount)

float

O

0

LayerAttachment

Policy layer attachment point (always treated as amount)

float

O

0

HoursClause

For perils with an inherent event duration, the insurance contract may contain an hours clause that limits the time in which claims can be added up and assigned to one event

int

O

n/a

PolPeril

Perils for policy financial terms

varchar(250)

CR

n/a

PolDedCode1Building

Policy building deductible code

tinyint

O

0

PolDedType1Building

Policy building deductible type

tinyint

CR

0

PolDed1Building

Policy building deductible

float

CR

0

PolMinDed1Building

Policy minimum building deductible

float

CR

0

PolMaxDed1Building

Policy maximum building deductible

float

CR

0

PolDedCode2Other

Policy other building deductible code

tinyint

O

0

PolDedType2Other

Policy other building deductible type

tinyint

CR

0

PolDed2Other

Policy other building deductible

float

CR

0

PolMinDed2Other

Policy minimum other building deductible

float

CR

0

PolMaxDed2Other

Policy maximum other building deductible

float

CR

0

PolDedCode3Contents

Policy contents deductible code

tinyint

O

0

PolDedType3Contents

Policy contents deductible type

tinyint

CR

0

PolDed3Contents

Policy contents deductible

float

CR

0

PolMinDed3Contents

Policy minimum contents deductible

float

CR

0

PolMaxDed3Contents

Policy maximum contents deductible

float

CR

0

PolDedCode4BI

Policy BI deductible code

tinyint

O

0

PolDedType4BI

Policy BI deductible type

tinyint

CR

0

PolDed4BI

Policy BI deductible

float

CR

0

PolMinDed4BI

Policy minimum BI deductible

float

CR

0

PolMaxDed4BI

Policy maximum BI deductible

float

CR

0

PolDedCode5PD

Policy PD deductible code

tinyint

O

0

PolDedType5PD

Policy PD deductible type

tinyint

CR

0

PolDed5PD

Policy PD deductible

float

CR

0

PolMinDed5PD

Policy minimum PD deductible

float

CR

0

PolMaxDed5PD

Policy maximum PD deductible

float

CR

0

PolDedCode6All

Policy blanket deductible code

tinyint

O

0

PolDedType6All

Policy blanket deductible type

tinyint

CR

0

PolDed6All

Policy blanket deductible

float

CR

0

PolMinDed6All

Policy minimum blanket deductible

float

CR

0

PolMaxDed6All

Policy maximum blanket deductible

float

CR

0

PolLimitCode1Building

Policy building limit code

tinyint

O

0

PolLimitType1Building

Policy building limit type

tinyint

CR

0

PolLimit1Building

Policy building limit

float

CR

0

PolLimitCode2Other

Policy other building limit code

tinyint

O

0

PolLimitType2Other

Policy other building limit type

tinyint

CR

0

PolLimit2Other

Policy other building limit

float

CR

0

PolLimitCode3Contents

Policy contents limit code

tinyint

O

0

PolLimitType3Contents

Policy contents limit type

tinyint

CR

0

PolLimit3Contents

Policy contents limit

float

CR

0

PolLimitCode4BI

Policy BI limit code

tinyint

O

0

PolLimitType4BI

Policy BI limit type

tinyint

CR

0

PolLimit4BI

Policy BI limit

float

CR

0

PolLimitCode5PD

Policy PD limit code

tinyint

O

0

PolLimitType5PD

Policy PD limit type

tinyint

CR

0

PolLimit5PD

Policy PD limit

float

CR

0

PolLimitCode6All

Policy blanket limit code (annual aggregate only)

tinyint

O

0

PolLimitType6All

Policy blanket limit type

tinyint

CR

0

PolLimit6All

Policy blanket limit

float

CR

0

StepFunctionName

Step function name

varchar(30)

CR

n/a

StepTriggerType

Code that represents how, and for which coverages, pay-outs are triggered.

tinyint

CR

n/a

StepNumber

Number between 1 and 10 that is used to sort the step function in the correct order.

tinyint

CR

n/a

PayOutType

Refers to PayoutBuilding, PayoutContents, PayoutBuildingContents. Payout can be % TIV, % Loss, a monetary amount, or % Limit.

tinyint

CR

n/a

TriggerType

Refers to TriggerStart and TriggerEnd fields which could be specified as a % TIV, % Loss or a monetary amount.

tinyint

CR

n/a

TriggerBuildingStart

Starting value of the building damage range over which the corresponding pay-out(s) should be made.

float

CR

0

TriggerBuildingEnd

Ending value of the building damage range over which the corresponding pay-out(s) should be made.

float

CR

0

DeductibleBuilding

Building deductible that can be used, for example, to account for fire policies before applying step functions.

float

CR

0

PayOutBuildingStart

Pay-out amount for the building losses for this step. If a ramp policy then it represents the start payout value.

float

CR

0

PayOutBuildingEnd

Pay-out amount for the end-point building losses for this ramp. This field should only be used if you have a ramp policy to indicate the end of the building payout. Otherwise, it should be left blank.

float

CR

0

PayOutLimitBuilding

Pay-out limit for building

float

CR

0

TriggerContentsStart

Starting value of the content damage range over which the corresponding pay-out(s) should be made.

float

CR

0

TriggerContentsEnd

Ending value of the content damage range over which the corresponding pay-out(s) should be made.

float

CR

0

DeductibleContents

Content deductible that can be used, for example, to account for fire policies before applying step functions.

float

CR

0

PayOutContentsStart

Pay-out amount for the contents losses for this step. If a ramp policy then it represents the start payout value.

float

CR

0

PayOutContentsEnd

Pay-out amount for the end-point contents losses for this ramp. This field should only be used if you have a ramp policy to indicate the end of the contents payout. Otherwise, it should be left blank.

float

CR

0

PayOutLimitContents

Pay-out limit for contents

float

CR

0

TriggerBuildingContentsStart

Starting value of the building and content damage range over which the corresponding pay-out(s) should be made.

float

CR

0

TriggerBuildingContentsEnd

Ending value of the building and content damage range over which the corresponding pay-out(s) should be made.

float

CR

0

DeductibleBuildingContents

Building and contents deductible that can be used, for example, to account for fire policies before applying step functions.

float

CR

0

PayOutBuildingContentsStart

Pay-out amount for the building and contents losses for this step. If a ramp policy then it represents the start payout value.

float

CR

0

PayOutBuildingContentsEnd

Pay-out amount for the end-point building and contents losses for this ramp. This field should only be used if you have a ramp policy to indicate the end of the building and contents payout. Otherwise, it should be left blank.

float

CR

0

PayOutLimitBuildingContents

Pay-out limit for building and contents

float

CR

0

ExtraExpenseFactor

A factor that is applied to main coverage loss for extra expenses. This value, entered as a decimal, should be the same for all steps for a policy contract and must be a value >=0. For example, 0.12 for 12%.

float

CR

0

ExtraExpenseLimit

A limit that applies to the total extra expense loss

float

CR

0

DebrisRemovalFactor

A factor for a conditional coverage which tends to apply to all steps and is to cover Debris Removal. This value, entered as a decimal, should be the same for all steps for a policy contract and must be a value >=0. For example, 0.12 for 12%.

float

CR

0

MinimumTIV

Minimum replacement value for which pay-outs to the corresponding damage range will be allowed.

float

CR

0

ScaleFactor

Factor used to scale up calculated losses. This value, entered as a proportion, should be the same for all steps for a policy contract. Must be a value >0 and may be >1. For example, 0.12 would scale up losses by 12%.

float

CR

1

IsLimitAtDamage

Indicates whether the pay-out is limited by the actual ground-up loss.

tinyint

CR

0

PolUserDef1

Policy user defined field

varchar(100)

O

n/a

PolUserDef2

Policy user defined field

varchar(100)

O

n/a

PolUserDef3

Policy user defined field

varchar(100)

O

n/a

PolUserDef4

Policy user defined field

varchar(100)

O

n/a

PolUserDef5

Policy user defined field

varchar(100)

O

n/a

FlexiPolZZZ

Flexible field that is stored in FlexiPol table in ModifierName = ZZZ

varchar(40)

O

n/a

CondNumber

Condition number identifies a unique set of condition financial terms applicable to one or more CondTag’s.

varchar(20)

CR

n/a

CondName

Condition name.

varchar(40)

O

n/a

CondPriority

Condition priority: specifies the order in which special conditions apply if multiple conditions apply to one location.

int

CR

n/a

CondPeril

Perils for condition financial terms

varchar(250)

CR

n/a

CondDedCode1Building

Special condition building deductible code

tinyint

O

0

CondDedType1Building

Special condition building deductible type

tinyint

CR

0

CondDed1Building

Special condition building deductible

float

CR

0

CondMinDed1Building

Special condition minimum building deductible

float

CR

0

CondMaxDed1Building

Special condition maximum building deductible

float

CR

0

CondDedCode2Other

Special condition other building deductible code

tinyint

O

0

CondDedType2Other

Special condition other building deductible type

tinyint

CR

0

CondDed2Other

Special condition other building deductible

float

CR

0

CondMinDed2Other

Special condition minimum other building deductible

float

CR

0

CondMaxDed2Other

Special condition maximum other building deductible

float

CR

0

CondDedCode3Contents

Special condition contents deductible code

tinyint

O

0

CondDedType3Contents

Special condition contents deductible type

tinyint

CR

0

CondDed3Contents

Special condition contents deductible

float

CR

0

CondMinDed3Contents

Special condition minimum contents deductible

float

CR

0

CondMaxDed3Contents

Special condition maximum contents deductible

float

CR

0

CondDedCode4BI

Special condition BI deductible code

tinyint

O

0

CondDedType4BI

Special condition BI deductible type

tinyint

CR

0

CondDed4BI

Special condition BI deductible

float

CR

0

CondMinDed4BI

Special condition minimum BI deductible

float

CR

0

CondMaxDed4BI

Special condition maximum BI deductible

float

CR

0

CondDedCode5PD

Special condition PD deductible code

tinyint

O

0

CondDedType5PD

Special condition PD deductible type

tinyint

CR

0

CondDed5PD

Special condition PD deductible

float

CR

0

CondMinDed5PD

Special condition minimum PD deductible

float

CR

0

CondMaxDed5PD

Special condition maximum PD deductible

float

CR

0

CondDedCode6All

Special condition blanket deductible code

tinyint

O

0

CondDedType6All

Special condition blanket deductible type

tinyint

CR

0

CondDed6All

Special condition blanket deductible

float

CR

0

CondMinDed6All

Special condition minimum blanket deductible

float

CR

0

CondMaxDed6All

Special condition maximum blanket deductible

float

CR

0

CondLimitCode1Building

Special condition building limit code

tinyint

O

0

CondLimitType1Building

Special condition building limit type

tinyint

CR

0

CondLimit1Building

Special condition building limit

float

CR

0

CondLimitCode2Other

Special condition other building limit code

tinyint

O

0

CondLimitType2Other

Special condition other building limit type

tinyint

CR

0

CondLimit2Other

Special condition other building limit

float

CR

0

CondLimitCode3Contents

Special condition contents limit code

tinyint

O

0

CondLimitType3Contents

Special condition contents limit type

tinyint

CR

0

CondLimit3Contents

Special condition contents limit

float

CR

0

CondLimitCode4BI

Special condition BI limit code

tinyint

O

0

CondLimitType4BI

Special condition BI limit type

tinyint

CR

0

CondLimit4BI

Special condition BI limit

float

CR

0

CondLimitCode5PD

Special condition PD limit code

tinyint

O

0

CondLimitType5PD

Special condition PD limit type

tinyint

CR

0

CondLimit5PD

Special condition PD limit

float

CR

0

CondLimitCode6All

Special condition blanket limit code

tinyint

O

0

CondLimitType6All

Special condition blanket limit type

tinyint

CR

0

CondLimit6All

Special condition blanket limit

float

CR

0

CondClass

Flags whether a condition is a policy restriction

tinyint

O

0

CondTag

Identifies a group of locations which are subject to one or more conditions.

varchar(20)

CR

n/a

OEDVersion

The OED schema version of the file - ‘major, minor, patch’ format i.e. (2.0.0)

varchar(10)

O

latest version

OriginalCurrency

Original currency in which the business has been written before any conversions

char(3)

O

n/a

RateOfExchange

Rate of exchange used to convert the terms from OriginalCurrency

float

O

0

AccParticipation

Insurance company share of the account loss. Values between 0 to 1 (e.g. 12% entered as 0.12)

float

O

1

CompanyIDSchemeXX

Company identification scheme. Eg. DUNS, LEI. See ‘OtherValues’

varchar(5)

CR

n/a

CompanyIDCodeXX

Company identifier related to the CompanyIDScheme

int

CR

0

YearFounded

Year that insured entity founded to support company identification (YYYY format)

smallint

O

0

StreetAddress

Main street address of insured entity

nvarchar(100)

O

n/a

PostalCode

Postal code of main address for insured entity

nvarchar(20)

O

n/a

City

City of main address for insured entity

nvarchar(50)

O

n/a

CountryCode

Country code for the country of domicile of the insured entity - see ‘CountryValues’

char(2)

O

n/a

AreaCode

Area code of main address for insured entity - see ‘AreaCodeValues’

char(3)

O

n/a

IndustrySchemeXX

Industry scheme i.e NAISC, USSIC, UKSIC. See ‘OtherValues’

varchar(5)

CR

n/a

IndustryCodeXX

Industry code from the IndustryScheme - see ‘IndustryCodeValues’

int

CR

0

IndustryVintageXX

Vintage of Industry code used (YYYY format)

smallint

O

0

IndustryDescription

Concise industry description (associated with IndustryCode or free form)

nvarchar(250)

O

n/a

NumberOfEmployees

Most recent estimate of number of employees

int

O

0

AnnualRevenue

Most recent estimate for annual total gross income (not profit)

float

CR

0

AnnualRevenueCurrency

Currency for AnnualRevenue in three digit format. See ‘CurrencyValues’

char(3)

CR

n/a

GrossProfitMargin

Gross Profit Margin of company in percentage (0.1 = 10%)

float

O

0

NumberOfRecords

Estimated number of records accessed

int

O

0

URL

Link to website

varchar(250)

O

n/a

IsPackage

Policy Type - Standalone (0), Package (1)

smallint

n/a

0

PolDed

Policy Deductible (monetary value for all coverages - non-property)

float

n/a

0

StackedPolNumber

If not unique indicates policy stacking (e.g. policies part of same insurance tower)

varchar(20)

n/a

n/a

LayerAggAttachment

Policy layer attachment (aggregate basis)

float

n/a

0

LayerAggLimit

100% policy layer limit (aggregate basis)

float

n/a

0

PolLimitNPBI

Sub-limit for (non-property) BI - see ‘CoverageValues’

float

n/a

0

PolDedNPBI

Sub-deductible for (non-property) BI - see ‘CoverageValues’

float

n/a

0

PolLimitCBI

Sub-limit for CONTINGENT BI - see ‘CoverageValues’

float

n/a

0

PolDedCBI

Sub-deductible for CONTINGENT BI- see ‘CoverageValues’

float

n/a

0

PolLimitDIAS

Sub-limit for DIGITAL ASSETS - see ‘CoverageValues’

float

n/a

0

PolDedDIAS

Sub-deductible for DIGITAL ASSETS - see ‘CoverageValues’

float

n/a

0

PolLimitEXT

Sub-limit for EXTORTION - see ‘CoverageValues’

float

n/a

0

PolDedEXT

Sub-deductible for EXTORTION - see ‘CoverageValues’

float

n/a

0

PolLimitFIN

Sub-limit for FINANCIAL FRAUD - see ‘CoverageValues’

float

n/a

0

PolDedFIN

Sub-deductible for FINANCIAL FRAUD - see ‘CoverageValues’

float

n/a

0

PolLimitINRE

Sub-limit for INCIDENT RESPONSE - see ‘CoverageValues’

float

n/a

0

PolDedINRE

Sub-deductible for INCIDENT RESPONSE - see ‘CoverageValues’

float

n/a

0

PolLimitLIA

Sub-limit for LIABILITY - see ‘CoverageValues’

float

n/a

0

PolDedLIA

Sub-deductible for LIABILITY - see ‘CoverageValues’

float

n/a

0

PolLimitREG

Sub-limit for REGULATORY - see ‘CoverageValues’

float

n/a

0

PolDedREG

Sub-deductible for REGULATORY - see ‘CoverageValues’

float

n/a

0

PolLimitENO

Sub-limit for ERRORS & OMISSIONS - see ‘CoverageValues’

float

n/a

0

PolDedENO

Sub-deductible for ERRORS & OMISSIONS - see ‘CoverageValues’

float

n/a

0

LimitCurrency

Limit Currency for all Coverages - see ‘CurrencyValues’

char(3)

n/a

n/a

DedCurrency

Deductible Currency for all currencies - see ‘CurrencyValues’

char(3)

n/a

n/a

PolSIR

Self Insured Retention

float

n/a

0

PolCoverage

List of coverages in policy - see ‘CoverageValues’

varchar(250)

n/a

CYB’

OSVendor

Operating System, Code - see ‘OtherValues’

int

n/a

0

CloudVendor

Cloud vendor Code - see ‘OtherValues’

int

n/a

0

EmailVendor

Email vendor Code - see ‘OtherValues’

int

n/a

0

CRMVendor

Customer Relationship Management vendor code - see ‘OtherValues’

int

n/a

0

PatchPolicy

Cadence of patches to the ‘main system’ - 0-Unknown/1-Never/2-Daily/3-Weekly/4-Monthly/5-Annually/6-Ad-hoc

tinyint

n/a

0

BackUpFreq

Cadence of back-up of the ‘main servers’ - 0-Unknown/1-Never/2-Daily/3-Weekly/4-Monthly/5-Annually/6-Ad-hoc

tinyint

n/a

0

AreaName

AreaName of main address for insured entity - see ‘AreaCodeValues’

nvarchar(50)

O

n/a

CoverageClassDescription

Concise class of business description for the policy coverage (free form)

nvarchar(100)

n/a

n/a

CoverageTerritory

Concise territorial description for the policy coverage (free form)

nvarchar(100)

n/a

n/a

CoverageTrigger

Options: 0-Claims Made or 1-Losses Occurring or 2-Occurrence Reported

tinyint

n/a

0

IsGroupCover

Is the policy coverage extended to subsidiaries of the insured party; Options: 0-No or 1-Yes

smallint

n/a

0

DefenceCost

Options: 0-Outside the limit, 1-Inside the limit or 2-Not Covered

tinyint

n/a

0

BIWaitingPeriod

BI waiting period defined at policy level (in days)

float

n/a

0

BIPOI

BI period of indemnity defined at policy level (in days, in increments of 0.5 days). Default value = 365 (1 year).

float

n/a

365

InsuredName

Full legal name of insured party

nvarchar(100)

O

n/a

Reinsurance Info (ReinsInfo)

Field

Description

Data type

Status

Default

ReinsNumber

Reinsurance number

int

R

n/a

ReinsName

Reinsurance name

varchar(30)

O

n/a

ReinsLayerNumber

Reinsurance layer for information / ordering purposes

int

O

n/a

ReinsPeril

Perils for reinsurance financial terms

varchar(250)

R

n/a

ReinsInceptionDate

Reinsurance inception date - in ISO 8601 format: YYYY-MM-DD

smalldatetime

O

n/a

ReinsExpiryDate

Reinsurance expiry date - in ISO 8601 format: YYYY-MM-DD

smalldatetime

O

n/a

CededPercent

Reinsurance ceded percentage, entered as a proportion with values between 0 and 1 (e.g. 12% entered as 0.12). Used mainly in surplus treaties. Applies before other reinsurance terms.

float

O

1

RiskLimit

Reinsurance per-risk limit

float

CR

0

RiskAttachment

Reinsurance per-risk attachment point

float

CR

0

OccLimit

Reinsurance occurrence limit

float

O

0

OccAttachment

Reinsurance per occurrence attachment

float

O

0

OccFranchiseDed

Reinsurance franchise deductible

float

O

0

OccReverseFranchise

Reinsurance reverse franchise - a value of loss that, if exceeded, results in no payment being made for this event from the reinsurer to insurer.

float

O

0

AggLimit

Maximum amount payable under this treaty during the AggPeriod

float

O

0

AggAttachment

The aggregate monetary amount during a given AggPeriod that the resinured retains under this treaty

float

O

0

AggPeriod

Aggregate period associated with the aggregate limits and attachments (in days). Default value = 365 (1 year)

float

O

365

PlacedPercent

Percentage of the limit that has been placed in the reinsurance market, entered as a proportion with values between 0 and 1 (e.g. 12% entered as 0.12). Used for reinsurance treaties other than surplus, after other reinsurance terms.

float

R

n/a

ReinsCurrency

Reinsurance currency

char(3)

R

n/a

InuringPriority

Reinsurance inuring priority capturing the order in which reinsurance contracts apply. Treaties with lower number inuring priorities apply first.

tinyint

R

n/a

ReinsType

Type of reinsurance contract

varchar(3)

R

n/a

AttachmentBasis

Reinsurance attachment basis

char(2)

O

(‘LO’)

Reinstatement

Number of reinstatements

tinyint

O

n/a

ReinstatementCharge

Reinstatement charge as %; semi-colon separated if different for each reinstatement (e.g. 1-free, 2-50%, 3-100% should be entered as: 0;0.5;1). If all reinstatements are the same, then just one number is sufficient (e.g. 3 reinstatements at 100% should be entered as 1)

varchar(50)

O

n/a

ReinsPremium

Reinsurance premium

float

O

0

DeemedPercentPlaced

Deemed percent placed, entered as a proportion with values between 0 and 1. Used to represent notional contracts or any part of the contract being notional. For fully notional contracts, enter 1 (i.e. 100%). For partially placed contracts, enter any value between 0 and 1. For real contracts, enter 0.

float

O

0

ReinsFXrate

Reinsurance exchange rate (as the contractual reinsurance rate can be different from the actual exchange rates used for policies and locations)

float

O

1

TreatyShare

The percentage of a treaty that a given reinsurer may write, entered as a proportion with values between 0 to 1 (e.g. 12% entered as 0.12).

float

O

1

UseReinsDates

A flag to indicate if reinsurance contract dates or policy inception / expiry dates are to be considered when calculating losses (Y) or ignored (N).

char(1)

O

N

RiskLevel

Code to indicate the definition of ‘risk’ for the per-risk terms in this particular treaty (or portion of the treaty)

char(3)

CR

n/a

OEDVersion

The OED schema version of the file - ‘major, minor, patch’ format i.e. (2.0.0)

varchar(10)

O

latest version

OriginalCurrency

Original currency in which the business has been written before any conversions

char(3)

O

n/a

RateOfExchange

Rate of exchange used to convert the terms from OriginalCurrency

float

O

0

Reinsurance Scope (ReinsScope)

Field

Description

Data type

Status

Default

ReinsNumber

Reinsurance number to link with ReinsInfo file

int

R

n/a

PortNumber

Portfolio number: used for defining treaty scope in the reinsurance scope file

varchar(20)

CR

n/a

AccNumber

Account number: used for defining treaty scope in the reinsurance scope file

nvarchar(40)

CR

n/a

PolNumber

Policy number: used for defining treaty scope in the reinsurance scope file

varchar(20)

CR

n/a

LocGroup

Location group name: used for defining treaty scope in the reinsurance scope file

nvarchar(20)

O

n/a

LocNumber

Location number: used for defining treaty scope in the reinsurance scope file

nvarchar(20)

CR

n/a

CedantName

Cedant name: used for defining treaty scope in the reinsurance scope file

varchar(40)

O

n/a

ProducerName

Producer name: used for defining treaty scope in the reinsurance scope file

varchar(40)

O

n/a

LOB

Line of business: used for defining treaty scope in the reinsurance scope file

varchar(20)

O

n/a

CountryCode

Country code: used for defining treaty scope in the reinsurance scope file

char(2)

O

n/a

ReinsTag

Reinsurance tag: user defined field to for defining treaty scope in the reinsurance scope file

varchar(20)

O

n/a

CededPercent

Reinsurance ceded percentage, entered as a proportion with values between 0 and 1 (e.g. 12% entered as 0.12). Within the reinsurance scope file, CededPercent should only be entered for surplus share treaties.

float

CR

1

OEDVersion

The OED schema version of the file - ‘major, minor, patch’ format i.e. (2.0.0)

varchar(10)

O

latest version